3.6.1. pypago.misc.findsecnum — PyPAGO 1.0.1 documentation

# 3.6.1. pypago.misc.findsecnum

`pypago.misc.` `findsecnum`(model_sections, secplotname)

  Determines the index of a section in a list of sections

  Parameters: | model_sections (list) – list of the Pago sections where to find the section secplotname (str) – name of the section
  Returns: | index of the section within the list
  Return type: | int
  Raises: | error – if secplotname not found in MODEL_sections